# OSPFv3

Monitors status of OSPFv3 enabled devices

**Note**: on Cisco devices (IOS/IOS-XE) this checks will only work with default VRF and one OSPFv3 process.\
Also there can be only one address family in the OSPFv3 process. Anything else nedds SNMPv3 contexts.

**Note: see the [Wiki](https://thl-cmk.hopto.org/gitlab/checkmk/vendor-independent/ospfv3/-/wikis/home) for a sample IOS OSPFv3 configuration**

Collection of OSPFv3 checks
*  *ospfv3_general*: monitors the OSPFv3 overall status
*  *ospfv3_area*: monitors OSPFv3 areas
*  *ospfv3_interface*: monitors OSPFv3 enabled interfaces
*  *ospfv3_neighbor*:  monitors OSPFv3 neighbors (IPv6 only)
*  *ospfv3_virtuallink*: monitors OSPFv3 virtual links (IPv6 only)

---
### Download

* [ospfv3.mkp (latest version)](https://thl-cmk.hopto.org/gitlab/checkmk/vendor-independent/ospfv3/-/raw/master/ospfv3.mkp "Download latest version")

---                   
### Installation

You can install the package by uploading it to your CheckMK site and as site user run `mkp install ospfv3.mkp`.


In the Enterprise/Free edition of CheckMK you can use the GUI to install the package (_Setup_ -> _Extension Packages_ -> _Upload package_)

---
### Want to contribute?
Nice ;-) Have a look at the [contribution guidelines](CONTRIBUTING.md "Contributing")

---
### Check Info *ospfv3_general*

* *service*: this check creates the service *OSPFv3*
* *state*: **warning** if the OSPFv3 process is admin disabled (*shutdown*)
* *wato*: [(see WATO options OSPFv3 general)](/../../../-/raw/master/doc/wato-general.png "see WATO options OSPFv3 general") and [(see WATO discovery options OSPFv3 general)](/../../../-/raw/master/doc/wato-general-discovery.png "see WATO discovery options OSPFv3 general")
* *perfdata*:
    * LSA count
    * Etxternal LSA count
    * receive new LSA count

Sample output

![sample output](/doc/sample_ospfv3_general.png?raw=true "sample output")

---
### Check Info *ospfv3_area*

* *service*: this check creates one service per OSPFv3 area
* *state*: is always ok
* *wato*: none
* *perfdata*:
    * number of Autonomus System Border Routers (ASBRs)
    * number of Area Border Routers (ABRs)
    * Area LSA count
    * SPF runs
    * NSSA translator events

Sample output

![sample output](/doc/sample_ospfv3_area.png?raw=true "sample output")

---
### Check Info *ospfv3_interface*

* *service*: this check creates one service per OSPFv3 enabled interface
* *state*: 
    * **warning** if the OSPFv3 process is admin disabled (*shutdown*)
    * **warning** if the interface OSPFv3 state *waiting* or *standby*
    * **critical** if the interface OSPFv3 state *down*
* *wato*:  [(see WATO options OSPFv3 interface)](/../../../-/raw/master/doc/wato-interface.png "see WATO options OSPFv3 interface")
* *perfdata*:
    * Link LSA count
    * Events

Sample output

![sample output](/doc/sample_ospfv3_interface.png?raw=true "sample output")

---
### Check Info *ospfv3_neighbor*

* *service*: this check creates one service for each OSPFv3 neighbor
* *state*: 
    * **warning** if the OSPFv3 neighbor state in *attempt*, *init*, *exchangeStart*, *exchange* or *loading*
    * **critical** if the OSPFv3 neighbor state is *down*
* *wato*:  [(see WATO options OSPFv3 neighbor)](/../../../-/raw/master/doc/wato-neighbor.png "see WATO options OSPFv3 neighbor")
* *perfdata*:
    * queue length
    * Events

Sample output

![sample output](/doc/sample_ospfv3_neighbor.png?raw=true "sample output")

---
### Check Info *ospfv3_virtuallink*

* *state*: 
    * **warning** if the OSPFv3 virtual link state in *attempt*, *init*, *exchangeStart*, *exchange* or *loading*
    * **critical** if the OSPFv3 virtual link state is *down*
* *wato*: [(see WATO options OSPFv3 virtual link)](/../../../-/raw/master/doc/wato-virtual-link.png "see WATO options OSPFv3 virtual link")
* *perfdata*:
    * queue length
    * Events

Sample output

![sample output](/doc/sample_ospfv3_virtuallink.png?raw=true "sample output")

